==> FreeBSD-jasperreports-server-cp-4.7.0-maven-repository.zip: com/jaspersoft/jasperserver/api/engine/common/service/ReportExecutionStatusSearchCriteria.java <==
/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package com.jaspersoft.jasperserver.api.engine.common.service;


/**
 * criteria object to use for filtering report job service
 *
 * @author Ivan Chan (ichan@jaspersoft.com)
 * @version $Id: ReportExecutionStatusSearchCriteria.java 22253 2012-02-21 23:08:27Z ichan $
 * @since 4.7
 * @see com.jaspersoft.jasperserver.api.engine.scheduling.service.ReportSchedulingService#getReportExecutionStatusList(SchedulerReportExecutionStatusSearchCriteria searchCriteria);
 */
public class ReportExecutionStatusSearchCriteria {

    private String reportURI;

    public ReportExecutionStatusSearchCriteria() {};

    public void setReportURI(String reportURI) {
        this.reportURI = reportURI;
    }

    public String getReportURI() {
        return reportURI;
    }
}

==> FreeBSD-jasperreports-server-cp-5.1.0-maven-repository.zip: com/jaspersoft/jasperserver/api/engine/common/service/ReportExecutionStatusSearchCriteria.java <==
/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package com.jaspersoft.jasperserver.api.engine.common.service;


import com.jaspersoft.jasperserver.api.JasperServerAPI;

/**
 * criteria object to use for filtering report job service
 *
 * @author Ivan Chan (ichan@jaspersoft.com)
 * @version $Id: ReportExecutionStatusSearchCriteria.java 25010 2012-09-26 16:56:35Z sergey.prilukin $
 * @since 4.7
 * @see com.jaspersoft.jasperserver.api.engine.common.service.EngineService#getReportExecutionStatusList();
 */
@JasperServerAPI
public class ReportExecutionStatusSearchCriteria {

    private String reportURI;

    public ReportExecutionStatusSearchCriteria() {};

    public void setReportURI(String reportURI) {
        this.reportURI = reportURI;
    }

    public String getReportURI() {
        return reportURI;
    }
}
